@@ -1,24 +1,27 @@
 package CatalystX::Test::Most;
 use strictures;
+no warnings "uninitialized";
 use HTTP::Request::Common ( qw{ GET POST DELETE PUT } );
 use Test::More;
 use Test::Fatal;
 our $AUTHORITY = "cpan:ASHLEY";
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 our @EXPORT = ( qw{ GET POST DELETE PUT },
                 qw{ request ctx_request action_redirect },
                 qw{ exception },
-                qw{ ctx },
+                qw{ ctx mech },
                 grep { defined &{$_} } @Test::More::EXPORT );
 
+my ( $App, $Args ); # Save for mech.
 sub import {
-    my ( $package, $app, $args ) = @_;
+    my $package = shift;
+    ( $App, $Args ) = @_;
     my $calling_package = [ caller() ]->[0];
 
     strictures->import;
 
     require Catalyst::Test;
-    Catalyst::Test->import($app, $args);
+    Catalyst::Test->import($App, $Args);
 
     {
         no strict "refs";
@@ -35,6 +38,16 @@ sub import {
 
 sub ctx { [ ctx_request(@_) ]->[1] }
 
+# No args means function call.
+sub mech {
+    my $self = shift if $_[0] eq __PACKAGE__; # Toss it.
+    my @args = ( catalyst_app => +shift || $App );
+    push @args, shift if @_;
+    require Test::WWW::Mechanize::Catalyst;
+    Test::WWW::Mechanize::Catalyst
+          ->new( @args );
+}
+
 1;
 
 __END__
@@ -48,16 +61,31 @@ CatalystX::Test::Most - Test base pulling in L<Catalyst::Test>, L<Test::More>, L
 =head1 Synopsis
 
  use CatalystX::Test::Most "MyApp";
- ok request("/")->is_success, "/ is okay";
- is exception { request("/no-such-uri") }, undef,
-    "404s do not throw exceptions";
- is request("/no-such-uri")->code, 404, "And do return 404";
+
+ subtest "Tests with plain Catalyst::Test" => sub {
+     ok request("/")->is_success, "/ is okay";
+     is exception { request("/no-such-uri") }, undef,
+        "404s do not throw exceptions";
+     is request("/no-such-uri")->code, 404, "And do return 404";
+ };
+
+ subtest "Tests with Test::WWW::Mechanize::Catalyst" => sub {
+    my $mech = mech();
+    $mech->get_ok("/", "GET /");
+    $mech->content_contains("OHAI", "That's my app all right");
+ };
+
  done_testing();
 
- # ok 1 - / is okay
- # ok 2 - 404s do not throw exceptions
- # ok 3 - And do return 404
- # 1..3
+ #    ok 1 - / is okay
+ #    ok 2 - 404s do not throw exceptions
+ #    ok 3 - And do return 404
+ #    1..3
+ # ok 2 - Tests with plain Catalyst::Test
+ #    ok 1 - GET /
+ #    ok 2 - My app all right
+ #    1..2
+ # ok 3 - Tests with Test::WWW::Mechanize::Catalyst
 
 =head1 Exported Functions from Other Packages
 
@@ -73,7 +101,11 @@ All of its exported functions; see its documentation: L<Test::More>.
 
 See C<exception> in L<Test::Fatal>.
 
-=head1 New Function
+=head2 Test::WWW::Mechanize::Catalyst
+
+You have easy access to a L<Test::WWW::Mechanize::Catalyst> object. There are no related functions, just the object methods.
+
+=head1 New Functions
 
 =over 4
 
@@ -81,6 +113,10 @@ See C<exception> in L<Test::Fatal>.
 
 This is a wrapper to get the context object. It will only work on local tests (not remote servers).
 
+=item * C<mech>
+
+Get a L<Test::WWW::Mechanize::Catalyst> object. Unless specified, the app name and the arguments are recycled from the C<import> of L<CatalystX::Test::Most>.
+
 =back
 
 =head1 Notes
